# Generated by Django 3.2.8 on 2021-10-22 10:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dj_audit', '0003_auditlog_host_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='auditlog',
            name='response_body',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='auditlog',
            name='host_name',
            field=models.CharField(
                default='', max_length=200, verbose_name='Host Name'),
        ),
    ]
